import Component from '@glimmer/component';
import { tracked } from '@glimmer/tracking';
import { action } from '@ember/object';
import mapboxgl from 'mapbox-gl';
 
export default class PathEditorComponent extends Component {
 
 @tracked lat = 0
 @tracked lng = 0
 @tracked polyline = []
 startPoint
 geoJsonPolyline = {
   "geometry": {
     "coordinates": this.polyline,
     "type": "LineString"
   },
   "type": "Feature",
   "properties": {
     "name": "Cyclo path"
   }
 }
 initLayer = false
  
 @action
 async mapClicked({ target:map, point}) {
   let clickCoord = map.unproject(point);
   this.lat = clickCoord.lat;
   this.lng = clickCoord.lng;
   let newCoord = [this.lng, this.lat];
   this.polyline.push(newCoord);
 
   if (this.polyline.length == 1) {
     // First point special processing --> add a marker as starting point
     this.startPoint = new mapboxgl.Marker()
       .setLngLat([this.lng, this.lat]).addTo(map);
   } else {
       if (!this.initLayer) {
         map.addSource('cycling-path', { 'type': 'geojson', 'data': this.geoJsonPolyline });
         map.addLayer({
           'id': 'Drawn_cycling_path',
           'type': 'line',
           'source': 'cycling-path',
           'layout': {
             'line-cap': 'round'
           },
           'paint': {
               'line-dasharray': [1, 2],
               'line-color': '#f77',
               'line-width': 3
           }
       });
         this.initLayer=true;
       } else {
         map.getSource('cycling-path').setData(this.geoJsonPolyline);
       }
   }
 }
}
